@@ -204,6 +204,17 @@ class CompositeType(SerializableType):
     def constants(self) -> typing.List[Constant]:
         return [a for a in self.attributes if isinstance(a, Constant)]
 
+    @property
+    def inner_type(self) -> 'CompositeType':
+        """
+        If the concrete type is a decorator over another Composite (such as :class:`DelimitedType`),
+        this property provides access to the decorated instance.
+        Otherwise, returns the current instance reference unchanged.
+        This is intended for use in scenarios where the decoration is irrelevant and the user needs to know
+        the concrete type of the decorated instance.
+        """
+        return self
+
     @property
     def fixed_port_id(self) -> typing.Optional[int]:
         return self._fixed_port_id
@@ -499,6 +510,12 @@ class DelimitedType(CompositeType):
                 (self._extent, inner.extent)
             )
 
+        delimiter_header_bit_length = self._DEFAULT_DELIMITER_HEADER_BIT_LENGTH  # This may be made configurable later.
+        # This is to prevent the delimiter header from breaking the alignment of the following composite.
+        delimiter_header_bit_length = max(delimiter_header_bit_length, self.alignment_requirement)
+        self._delimiter_header_type = UnsignedIntegerType(delimiter_header_bit_length,
+                                                          UnsignedIntegerType.CastMode.TRUNCATED)
+
         assert self.extent % self.BITS_PER_BYTE == 0
         assert self.extent % self.alignment_requirement == 0
         assert self.extent >= self.inner_type.extent
@@ -555,10 +572,7 @@ class DelimitedType(CompositeType):
         The type of the integer prefix field that encodes the size of the serialized representation [in bytes]
         of the :attr:`inner_type`.
         """
-        bit_length = self._DEFAULT_DELIMITER_HEADER_BIT_LENGTH  # This may be made configurable later.
-        # This is to prevent the delimiter header from breaking the alignment of the following composite.
-        bit_length = max(bit_length, self.alignment_requirement)
-        return UnsignedIntegerType(bit_length, UnsignedIntegerType.CastMode.SATURATED)
+        return self._delimiter_header_type
 
     def iterate_fields_with_offsets(self, base_offset: typing.Optional[BitLengthSet] = None) \
             -> typing.Iterator[typing.Tuple[Field, BitLengthSet]]:
@@ -741,15 +755,19 @@ def _unittest_composite_types() -> None:
         assert s['']        # Padding fields are not accessible
     assert hash(s) == hash(s)
     assert not s.has_parent_service
+    assert s.inner_type is s
+    assert s.inner_type.inner_type is s
 
     d = DelimitedType(s, 2048)
     assert d.inner_type is s
+    assert d.inner_type.inner_type is s
     assert d.attributes == d.inner_type.attributes
     with raises(KeyError):
         assert d['c']
     assert hash(d) == hash(d)
     assert d.delimiter_header_type.bit_length == 32
     assert isinstance(d.delimiter_header_type, UnsignedIntegerType)
+    assert d.delimiter_header_type.cast_mode == PrimitiveType.CastMode.TRUNCATED
     assert d.extent == 2048
 
     d = DelimitedType(s, 256)
@@ -787,6 +805,8 @@ def _unittest_composite_types() -> None:
         UnsignedIntegerType(16, PrimitiveType.CastMode.TRUNCATED),
         SignedIntegerType(16, PrimitiveType.CastMode.SATURATED),
     ])
+    assert u.inner_type is u
+    assert u.inner_type.inner_type is u
     assert u.bit_length_set == {24}
     assert u.extent == 24
     assert DelimitedType(u, 40).extent == 40
@@ -796,6 +816,8 @@ def _unittest_composite_types() -> None:
     assert DelimitedType(u, 32).extent == 32
     assert DelimitedType(u, 32).bit_length_set == {32, 40, 48, 56, 64}
     assert DelimitedType(u, 800).extent == 800
+    assert DelimitedType(u, 800).inner_type is u
+    assert DelimitedType(u, 800).inner_type.inner_type is u
 
     assert try_union_fields(
         [
